# jangan hapus dev && gua gban lo

# rendy  : 1191668125, 5915945719, 901878554
# risman : 182990552, 844432220
# yanto : 730988759
# kenkan : 1607338903
# kyy : 1663258664
# riz : 951454060

DEVS = [
    1191668125,
    5915945719,
    182990552,
    844432220,
    730988759,
    1607338903,
    1663258664,
    901878554,
    951454060,
]

# jangan hapus grup && gua gban lo

# ZAID SUPPORT : -1001521704453
# JAMET SEXY : -1001704645461
# KILLEX SUPPORT : -1001554560763
# SHARING USERBOT : -1001473548283
# ULTROID SUPPORT : -1001361294038
# PYROGRAM : -1001387666944
# YUKKI : -1001733534088
# nasy : -1001380293847
# aruna : -1001347414136
# ayin support: -1001675396283
# cilik support: -1001687155877
# bagas support : -1001795125065
# group booster : -1001101697396
# durov : -1001256902287
# android apk : -1001212593743
# bruno : -1001084578942
# aot : -1001070335805
# telegram bot : -1001311056733

GROUP = [
    -1001387666944, # pyrogram 
    -1001521704453, # zaid support
    -1001704645461, # jamet support
    -1001554560763, # kilerx support
    -1001473548283, # sharing userbot
    -1001361294038, # Ultroid Support
    -1001733534088, # yukki support 
    -1001380293847, # nasty support
    -1001347414136, # aruna
    -1001675396283, # ayin
    -1001687155877, # cilik support 
    -1001795125065, # bagas support
    -1001101697396, # group booster
    -1001256902287, # durov
    -1001212593743, # android apk
    -1001084578942, # bruno support
    -1001070335805, # aot
    -1001311056733, # telegram bot
]
